bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 14. Aventiure
___________________________________________________ #### Aventivre wie die chvniginne #### mit ander zerwrfen
###### 814 | ### Vor einer vespercite | hovp sich groz vngemach ### daz von manigem recken | vf dem hove geschach ### si pflagen ritterschepfte | dvrch chvercewile wan ### do lieffen dar dvrch schowen | vil manich wip vnde man
###### 815 | ### zesamene do gesazen | di kveneginne rich ### si gedahten zweir recken | di waren lobelich ### do sprach div schoene criemhilt | ich han einen man ### daz elliv disiv riche | ce sinen handen solden stan
###### 816 | ### do sprach div vrov prvnnhilt | wi chvnde daz gesin ### ob ander niemen lebte | wan sin vnde din ### so mohten im div riche | wol wesen vndertan ### di wile lebt gvnther | so chvnd ez nimmer ergan
###### 817 | ### do sprach aber criemhilt | nv sihestv wi er stat ### wi rehte herliche er | vor den recken gat ### alsam der liehte mane | vor den sternen tvt ### des mvz ich von schvlden | tragen vrolichen mvt
###### 818 | ### do sprach div vrov prvnnhilt | swi waetlich si din man ### swi edele vnt swi shoene | so mvst tv vor im lan ### gvnther den recken | den edeln brvder din ### der mvz vor allen chvenegen | daz wizest waerliche sin
###### 819 | ### do sprach do vrov criemhilt | so tiwer ist wol min man ### daz ich in ane schvlde | niht gelobet han ### an vil manegen dingen | so ist sin ere groz ### gelovbestv des prvenhilt | er ist wol gvnthers genoz
###### 820 | ### ia ne solt dv mirz criemhilt | ce arge niht verstan ### wand ich ane schvlde | di rede niht han getan ### ich horte si iehen beide | do ichs allererste sach ### vnd da des chveneges wille | an minem libe geschach
###### 821 | ### vnt da er mine minne | so ritterlich gewan ### da iach des selbe sifrit | er waere skveneges man ### des han ich in fver eigen | sit ich es in hoere iehen ### dv sprach div shone criemhilt | so waere mir vebele geshaehen
###### 822 | ### wi heten so geworben | di edelen brvder min ### daz ich eigenmannes | wine solde sin ### des wil ich dich prvnnhilt | vil frivntliche bitten ### daz dv di rede lazest | dvrch mich mit gvetlichen sitten
###### 823 | ### ia ne mach ir niht gelazen | sprach des chveneges wip ### zwiv sold ich verchiesen | so maniges ritters lip ### der vns mit dem degene | dienestlich ist vndertan ### criemhilt div vil schone | vil sere zvernen began
###### 824 | ### dv mvst in verchiesen | daz er dir immer bi ### wone deheiner dieneste | er ist tiwerr danre si ### gvnther der min brvder | der vil edel man ### dv solt mich des erlazen | daz ich von dir vernomen han
###### 825 | ### vnde nimet mich immer wunder | sit er din eigen ist ### vnt daz vber vns beide | so gewaltech bist ### daz er dir so lange | den cins versezzen hat ### der diner vebermvete | sold ich von rehte haben rat
###### 826 | ### dv zivhest dich ce hohe | sprach des chveniges wip ### nv wil ich saehen gerne | op man den dinen lip ### habe ce solhen eren | so man den minen tvt ### di vrowen wurden beide | vil sere zornech gemvt
###### 827 | ### do sprach div vrowe criemhilt | daz mvz et nv geschaehen ### sit dv mines mannes | fvr eigen hast veriehen ### nv mvezzen hivte chiesen | der beide chvenige man ### op ich vor chveniges wibe | cem mvnster tvrre gan
###### 828 | ### dv mvst da hivte schowen | daz ich pin edelvri ### vnt daz min man ist tiwerr | danne der dine si ### damit wil ich selbe | niht bescholten sin ### dv solt noch hinte chiesen | wi div eigene div din
###### 829 | ### ce hove ge vor recken | in bvergenden lant ### ich wil selbe tiwerr wesen | danne iemen habe bechant ### deheine chvneginne | div chron ie her getrvch ### do hvp sich vnder den vrowen | des grozen nides genvch
###### 830 | ### do sprach aber prvnnhilt | wiltv niht eigen sin ### so mvstv dich scheiden | mit den vrowen din ### von minem ingesinde | da wir cem mvenster gan ### des antwurte criemhilt | entriwen daz sol sin getan
###### 831 | ### nv chleidete ivch mine meide | sprach sifrides wip ### ez mvz ane schande | beliben hie min lip ### ir svlt wol lazen schowen | vnd habt ir riche wat ### si mach sin gerne lovgen | des prvennhilt veriehen hat
###### 832 | ### man moht in lihte raten | si svchten richiv chleit ### da wart vil wol gecieret | manich vrowe vnde meit ### do gi mit ir gesinde | des edelen chveniges wip ### do wart ovch wol gecieret | der schonen criemhilden wip
###### 833 | ### mit drin vnd vierzech meiden | di brahte si an den rin ### di trvgen liehte pfelle | geworht in araby ### svs chomen zv dem mvenster | di meide wolgetan ### ir warten vor dem hvse | alle sifrides man
###### 834 | ### di livte nam des wunder | wavon daz gesach ### daz man di chveneginne | also gescheiden sach ### daz si bi einander | niht giengen alsam e ### davon wart manigem degene | sit vil sorchlichen we
###### 835 | ### hie stvnt vor dem mvenster | daz gvntheres wip ### do hete chvrcewile | vil maniges ritters lip ### mit den schoenen vrowen | der si da namen war ### do chom div vrov criemhilt | mit maniger herlichen schar
###### 836 | ### swaz chleider ie getrvgen | edeler ritter chint ### wider ir gesinde | daz was gar ein wint ### si was so rich des gvtes | daz drizech kvenige wip ### ez mohten niht erzivgen | daz taete criemhilde lip
###### 837 | ### ob iemen wuenshen solde | der chvnde niht gesagen ### daz man so richiv chleider | gesaehe ie mere tragen ### also da ce stvnden trvgen | ir meide wolgetan ### wan ce leide prvennhilde | ez hete criemhilt verlan
###### 838 | ### zesamne si do chomen | vor dem mvenster wit ### ez tet div hvsvrowe | dvrch einen grozzen nit ### si hiez vil vebelliche | criemhilde stille stan ### ia sol vor chveniges wibe | nimmer eigendiv gegan
###### 839 | ### do sprach div schone criemhilt | zornech was ir mvt ### chvndestv noch geswigen | daz waere dir gvt ### dv hast geshendet selbe | den dinen schoenen lip ### wi mohte mannes chebse | werden immer chveniges wip
###### 840 | ### wen hastv hie verschebset | sprach do des chveniges wip ### daz tvn ich sprach criemhilt | den dinen schoenen lip ### den minnet erste sifrit | der min vil lieber man ### ia ne was ez niht min brvder | der dir den magetvm angewan
###### 841 | ### war chomen dine sinne | ez was ein arger list ### zwiv lieze dv in minnen | sit er din eigen ist ### ich hoere dich sprach criemhilt | an alle schvlde chlagen ### entriwen sprach do prvennhilt | daz wil ich gvnthere sagen
###### 842 | ### waz mach mir daz gewerren | din vebermvt dich hat betrogen ### dv hast mich ce dieneste | mit rede dich angezogen ### daz wizze en rehten triwen | ez ist mir immer leit ### getriwer heinliche | sol ich dir wesen vmbereit
###### 843 | ### prvnnhilt do weinende | criemhilt niht langer lie ### vor des chvniges wibe | inz mvenster si do gie ### mit ir ingesinde | daz hvp sich grozer haz ### des wurden ir liehtiv ovgen | vil starche trveb vnd naz
###### 844 | ### swi vil man gote gediende | oder iemen da gesanch ### des dvhte prvnnhilde | div wile gar ce lanch ### wand ir was vil trvebe | der lip vnd ovch der mvt ### des mvose sit engelten | manich helt chven vnd gvt
###### 845 | ### prvnnhilt gi mit ir vrowen | fver daz mvenster stan ### si gedahte mich mvz criemhilt | mere horen lan ### des mich so lvte zihet | daz wortreze wip ### hat er sich es gervemet | ez get an sifrides lip
###### 846 | ### nv chom div edele criemhilt | mit manigem chvenem man ### do sprach div vrowe prvnnhilt | ir svlt noch stille stan ### ir iahet min ce chebesen | daz svlt ir mich lazen sehen ### mir ist von iwern sprvchen | daz wizzet leide geschehen
###### 847 | ### do sprach div vrowe criemhilt | ir mohtet mich lazen gan ### ich erzivge ez mit dem golde | daz ich an der hende han ### daz brahte mir min vriedel | do er erste bi mir lach ### ni gelebte prvnnhilt | deheinen leidern tach
###### 848 | ### si sprach diz golt vil edele | daz wart mir verstoln ### vnd ist mich harte lange | vil veble vor verholn ### ich chvmes an ein ende | wer mir ez hat genomen ### di vrowen waren beide | in groz vngemvete chomen
###### 849 | ### do sprach aber criemhilt | ine wils niht wesen diep ### dv mohtes wol gedaht han | vnd were dir ere lip ### ich erzivgez mit dem gvertel | den ich hie vmbe han ### daz ich niht livge | ia wart min sifrit din man
###### 850 | ### von ninnive der siden | si den porten trvch ### mit edelem gesteine | ia was er gvt genvch ### do den gesach vrov prvnnhilt | weinen si began ### daz mvsen vreischen gvnther | vnd alle bvergvnden man
###### 851 | ### do sprach div chvneginne | heizet here gan ### den fvrsten vonme rine | ich wil in hoeren lan ### wi mich hat gehoenet | siner swester lip ### si sagt hie offenliche | ich si sifrides wip
###### 852 | ### der kvenich chom mit recken | weinen er do sach ### di sine trivttinne | wi gvetlich er sprach ### sagt mir liebiv vrowe | wer hat iv iht getan ### si sprach zv dem kvenige | ich mvz vnvroeliche stan
###### 853 | ### von allen minen eren | mich div swester din ### gerne wolde scheiden | dir sol gechlaget sin ### si ght mich habe gechebset | sifrit ir man ### do sprach der chvenech gvnther | so hetes vebele getan
###### 854 | ### si treit hie minen gvrtel | den ich han verlorn ### vnd min golt daz rote | daz ich ie wart geborn ### daz riwet mich vil sere | dv ne beredest chvenich mich ### der vil grozen schande | daz diene ich chvenech immer vmbe dich
###### 855 | ### do sprach der chvenich gvnther | er sol her fver gan ### vnd hat er sis gervemet | daz sol er hoeren lan ### oder sin mvz lovgen | der helt von niderlant ### den criemhilde vriedel | den hiez man bringen sa cehant
###### 856 | ### do der herre sifrit | di vngemveten sach ### ern wesse niht der maere | wi balde er do sprach ### waz weinent dise vrowen | daz het ich gerne erchant ### oder von welhen schvlden | mich der chvnich habe besant
###### 857 | ### do sprach der chvenich gvnther | ia ist mir harte leit ### mir hat min vrowe prvnnhilt | ein maere hie geseit ### dv habes dich des gervemet | daz dv ir schoenen lip ### allererst habes geminnet | daz sagt criemhilt din wip
###### 858 | ### do sprach der starche sifrit | vnd hat si daz geseit ### e daz ich erwinde | ez sol ir werden leit ### vnd wil dir daz enpfveren | vor allen dinen man ### mit minen hohen eiden | daz ich es niht gesaget han
###### 859 | ### do sprach der chvnich von rine | daz soltv lazen sehen ### den eit den dv da bivtest | vnt mach der hie geschehen ### aller valschen dinge | der wil ich dich ledich lan ### do hiez man zv dem ringe | di stolzen bvrgvnden stan
###### 860 | ### sifrit der vil chvene | cem eide bot di hant ### do sprach der chvenich riche | mir ist so wol bechant ### iwer groz vnschvlde | ich wil iv ledich lan ### des ivch min swester zihet | daz ir des nine habt getan
###### 861 | ### do sprach aber sifrit | genivzzet es min wip ### daz si hat betrevbt | den prvennhilde lip ### daz ist mir sicherlichen | ane maze leit ### do sahen zv zeinander | di gvten ritter gemeit
###### 862 | ### man sol vrowen ziehen | sprach sifrit der degen ### daz si vppechliche sprveche | lazen vnder wegen ### verbivtez dinem wibe | der minen tvn ich sam ### ir grozen vngefvge | ich mich waerliche sham
###### 863 | ### mit rede was gescheiden | manich schoene wip ### do trvret also sere | der prvnnhilde lip ### daz ez barmen mvse | den gvntheres man ### do chom von tronege hagene | zv siner vrowen gegan
###### 864 | ### er vragete waz ir waere | weinende er si vant ### do sagte si im div maere | er lobt ir sa cehant ### daz ez erarnen mvese | der criemhilde man ### oder er wolde nimmer | darvmbe vrolich gestan
###### 865 | ### zv der rede chom do ortwin | vnt gernot ### da di helde rieten | den sifrides tot ### darzv chom ovch giselher | der edelen vten chint ### do er ir rede gehorte | er sprach getriweliche sint
###### 866 | ### ir vil gvten recken | warvmbe tvt ir daz ### ia ne gediente sifrit | nie alsolhen haz ### daz er darvmbe solde | verliesen sinen lip ### ia ist es harte lihte | darvmbe zvernent div wip
###### 867 | ### svln wir govche ziehen | sprach aber hagene ### des habent vil lvecel ere | so gvte degene ### daz er sich hat gervemet | der lieben vrowen min ### darvmbe wil ich sterben | ez en ge im an daz leben sin
###### 868 | ### do sprach der chvenich selbe | ern hat vns niht getan ### niwan gvt vnd ere | man sol in lebn lan ### waz tovch ob ich dem recken | nv waere gaehaz ### er was ie getriwe | vnd tet vil willechliche daz
###### 869 | ### do sprach von metzen | der degen ortwin ### ia ne mach in niht gehelffen | div groze sterche sin ### erlovbet mirz min herre | ich getv im leit ### do heten im di helde | ane schvlde widerseit
###### 870 | ### sin gevolgete niemen | niwan daz hagen geriet ### in allen citen gvnther | dem degene ob sifride ### niht en lebte | so wurde im vndertan ### vil der chvenege lande | der helt des trvren began
###### 871 | ### do liezen siz beliben | spiln man do sach ### hey waz man starcher scheffte | vor dem mvnster brach ### vor sifrides wibe | al zv dem sale dan ### do waren in vmmvte | alle gvntheres man
###### 872 | ### der chvenich sprach lat beliben | den mortlichen zorn ### er ist vns ce saelden | vnt ce eren geborn ### ovch ist so grimme starch | der wundernchvne man ### ob er sin innen wuerde | so torste in niemen bestan
###### 873 | ### nein er sprach do hagene | ir mvget wol stille dagen ### ich getruwez heinliche | also wol angetragen ### daz prvnnhilde weinen | sol im wesen leit ### ia sol im von hagenen | immer wesen widerseit
###### 874 | ### do sprach der chvenich gvnther | wi mach daz ergan ### des antwurte hagene | ich wilz ivch horen lan ### wir heizen botten | zv zvns in diz lant ### widersagen offenliche | di hie nimen sin bechant
###### 875 | ### so ieht ir vor den gesten | daz ir vnd iwer man ### wellet herverten | also daz ist getan ### so lobt er iv dar dienen | des vlivset er den lip ### so ervar ich vns div maere | ab des chvnen recken wip
###### 876 | ### der chvenich gevolgete vbele | hagenen sinem man ### di starchen vntriwe | begonden tragen an ### e iemen daz erfvnde | di ritter vzerchorn ### von zweier vrowen bagen wart | vil manich helt verlorn

<<< Übersicht <<< vorige Seite nächste Seite >>>